# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

#' The Four Parameter Beta Distribution
#' 
#' @description Density, distribution function, quantile function and 
#'              random generation for the four parameter Beta distribution 
#'              with minimum value \code{min} and scale \code{scale}.
#'              
#' @details If \code{shape} is not specified, a default 
#'          value of 1 is used.
#'          
#'          The Birmbaum-Saunders distribution with shape \eqn{\beta} and
#'          scale \eqn{\theta} has density
#'          
#'          \deqn{f(x;\theta,\beta) = \frac{\sqrt{\frac{x}{\theta}}+\sqrt{\frac{\theta}{x}}}{2\beta x}\phi_{_{NOR}(z)},\quad x \ge 0 }
#'          
#'          where \eqn{\phi_{_{NOR}}(z)} is the density of the standard normal distribution and  
#'          
#'          \deqn{z = \frac{1}{\beta}\left(\sqrt{\frac{x}{\theta}}-\sqrt{\frac{\theta}{x} } \right)}.
#'          
#' @return \code{dbeta4} gives the density, 
#'         \code{pbeta4} gives the distribution function, 
#'         \code{qbeta4} gives the quantile function, and 
#'         \code{rbeta4} generates random observations.
#'         
#'         The length of the result is determined by \code{n} 
#'         for \code{rbeta4}, and is the maximum of the lengths 
#'         of the numerical arguments for the other functions. 
#'         
#'         The numerical arguments other than \code{n} are 
#'         recycled to the length of the result.   
#'          
#' @source Birnbaum, Z. W.; Saunders, S. C. (1969), "A new family of life distributions", Journal of Applied Probability, 6 (2): 319–327, JSTOR 3212003, doi:10.2307/3212003
#' @export
#' @rdname beta4
#' @name Four Parameter Beta
#' @param p Vector of probabilities
#' @param x Vector of quantiles
#' @param q Vector of quantiles
#' @param n Number of observations
#' @param min The minumum value on which the distribution is defined
#' @param max The maximum value on which the distribution is defined
#' @param shape1 Shape parameter
#' @param shape2 Shape parameter
#' @param gap Spacing from \code{min} and \code{max}
#' @export
dbeta4 <- function(x, min, max, shape1, shape2, gap = 0) {
    .Call(`_teachingApps_dbeta4`, x, min, max, shape1, shape2, gap)
}

#' @export
#' @rdname beta4
#' @import RcppNumerical
pbeta4 <- function(q, min, max, shape1, shape2, gap = 0) {
    .Call(`_teachingApps_pbeta4`, q, min, max, shape1, shape2, gap)
}

#' @export
#' @rdname beta4
qbeta4 <- function(p, min, max, shape1, shape2) {
    .Call(`_teachingApps_qbeta4`, p, min, max, shape1, shape2)
}

#' @export
#' @rdname beta4
rbeta4 <- function(n, min, max, shape1, shape2) {
    .Call(`_teachingApps_rbeta4`, n, min, max, shape1, shape2)
}

#' The Birmbaum-Saunders Distribution
#' 
#' @description Density, distribution function, quantile function and 
#'              random generation for the BISA distribution with location
#'              \code{loc} and scale \code{scale}.
#'              
#' @details If \code{shape} is not specified, a default 
#'          value of 1 is used.
#'          
#'          The Birmbaum-Saunders distribution with shape \eqn{\beta} and
#'          scale \eqn{\theta} has density
#'          
#'          \deqn{f(x;\theta,\beta) = \frac{\sqrt{\frac{x}{\theta}}+\sqrt{\frac{\theta}{x}}}{2\beta x}\phi_{_{NOR}(z)},\quad x \ge 0 }
#'          
#'          where \eqn{\phi_{_{NOR}}(z)} is the density of the standard normal distribution and  
#'          
#'          \deqn{z = \frac{1}{\beta}\left(\sqrt{\frac{x}{\theta}}-\sqrt{\frac{\theta}{x} } \right)}.
#'          
#' @return \code{dbisa} gives the density, 
#'         \code{pbisa} gives the distribution function, 
#'         \code{qbisa} gives the quantile function, and 
#'         \code{rbisa} generates random observations.
#'         
#'         The length of the result is determined by \code{n} 
#'         for \code{rbisa}, and is the maximum of the lengths 
#'         of the numerical arguments for the other functions. 
#'         
#'         The numerical arguments other than \code{n} are 
#'         recycled to the length of the result.   
#'          
#' @source Birnbaum, Z. W.; Saunders, S. C. (1969), "A new family of life distributions", Journal of Applied Probability, 6 (2): 319–327, JSTOR 3212003, doi:10.2307/3212003
#' @export
#' @rdname bisa
#' @name Birmbaum-Saunders
#' @param p Vector of probabilities
#' @param x Vector of quantiles
#' @param q Vector of quantiles
#' @param n Number of observations
#' @param shape Shape parameter
#' @param scale Scale parameter
qbisa <- function(p, shape, scale = 1) {
    .Call(`_teachingApps_qbisa`, p, shape, scale)
}

#' @export
#' @rdname bisa
pbisa <- function(q, shape, scale = 1) {
    .Call(`_teachingApps_pbisa`, q, shape, scale)
}

dlbisa <- function(z, shape) {
    .Call(`_teachingApps_dlbisa`, z, shape)
}

#' @export
#' @rdname bisa
dbisa <- function(x, shape, scale = 1) {
    .Call(`_teachingApps_dbisa`, x, shape, scale)
}

#' @export
#' @rdname bisa
rbisa <- function(n, shape, scale = 1) {
    .Call(`_teachingApps_rbisa`, n, shape, scale)
}

#' The Largest Extreme Value Distribution
#' @description Density, distribution function, quantile function and 
#'              random generation for the LEV distribution with location
#'              \code{loc} and scale \code{scale}.
#'              
#' @details If \code{loc} is not specified, a default 
#'          value of 0 is used. If \code{scale} is not 
#'          specified, a default value of 1 is used.
#'          
#'          The largest extreme value distribution with 
#'          location parameter \eqn{\mu} and
#'          scale \eqn{\sigma} has density
#'          
#'          \deqn{f(x;\mu,\sigma) = \frac{1}{\sigma}\phi_{_{LEV}}\left(\frac{x-\mu}{\sigma}\right),\quad -\infty < x < \infty }
#'          
#'          where \eqn{\phi_{_{LEV}}(z)} exp[-z - exp(-z)] is the density of the standard LEV distribution.
#'          
#' @return \code{dlev} gives the density, 
#'         \code{plev} gives the distribution function, 
#'         \code{qlev} gives the quantile function, and 
#'         \code{rlev} generates random observations.
#'         
#'         The length of the result is determined by \code{n} 
#'         for \code{rlev}, and is the maximum of the lengths 
#'         of the numerical arguments for the other functions. 
#'         
#'         The numerical arguments other than \code{n} are 
#'         recycled to the length of the result.   
#'         
#' @export
#' @rdname lev
#' @name Largest Extreme Value
#' @param p Vector of probabilities
#' @param x Vector of quantiles
#' @param q Vector of quantiles
#' @param n Number of observations
#' @param loc Location parameter
#' @param scale Scale parameter
qlev <- function(p, loc = 0, scale = 1) {
    .Call(`_teachingApps_qlev`, p, loc, scale)
}

#' @export
#' @rdname lev
plev <- function(q, loc = 0, scale = 1) {
    .Call(`_teachingApps_plev`, q, loc, scale)
}

#' @export
#' @rdname lev
dlev <- function(x, loc = 0, scale = 1) {
    .Call(`_teachingApps_dlev`, x, loc, scale)
}

#' @export
#' @rdname lev
rlev <- function(n, loc = 0, scale = 1) {
    .Call(`_teachingApps_rlev`, n, loc, scale)
}

likely2 <- function(times, cens, params, maxll) {
    .Call(`_teachingApps_likely2`, times, cens, params, maxll)
}

#' The Smallest Extreme Value Distribution
#' @description Density, distribution function, quantile function and 
#'              random generation for the SEV distribution with location
#'              \code{loc} and scale \code{scale}.
#'              
#' @details If \code{loc} is not specified, a default 
#'          value of 0 is used. If \code{scale} is not 
#'          specified, a default value of 1 is used.
#'          
#'          The smallest extreme value distribution with 
#'          location parameter \eqn{\mu} and
#'          scale \eqn{\sigma} has density
#'          
#'          \deqn{f(x;\mu,\sigma) = \frac{1}{\sigma}\phi_{_{SEV}}\left(\frac{x-\mu}{\sigma}\right),\quad -\infty < x < \infty }
#'          
#'          where \eqn{\phi_{_{SEV}}(z)} exp[z - exp(z)] is the density of the standard LEV distribution.
#'          
#' @return \code{dsev} gives the density, 
#'         \code{psev} gives the distribution function, 
#'         \code{qsev} gives the quantile function, and 
#'         \code{rsev} generates random observations.
#'         
#'         The length of the result is determined by \code{n} 
#'         for \code{rsev}, and is the maximum of the lengths 
#'         of the numerical arguments for the other functions. 
#'         
#'         The numerical arguments other than \code{n} are 
#'         recycled to the length of the result.   
#' @export
#' @rdname sev
#' @name Smallest Extreme Value
#' @param p Vector of probabilities
#' @param x Vector of quantiles
#' @param q Vector of quantiles
#' @param n Number of observations
#' @param loc Location parameter
#' @param scale Scale parameter
qsev <- function(p, loc = 0, scale = 1) {
    .Call(`_teachingApps_qsev`, p, loc, scale)
}

#' @export
#' @rdname sev
psev <- function(q, loc = 0, scale = 1) {
    .Call(`_teachingApps_psev`, q, loc, scale)
}

#' @export
#' @rdname sev
dsev <- function(x, loc = 0, scale = 1) {
    .Call(`_teachingApps_dsev`, x, loc, scale)
}

#' @export
#' @rdname sev
rsev <- function(n, loc = 0, scale = 1) {
    .Call(`_teachingApps_rsev`, n, loc, scale)
}

